---
title: Mettre en place un serveur Miniflux
---

# Mettre en place un serveur Miniflux

Miniflux est un agrégateur de flux libre écrit en Go assez simple à mettre en place.

{{<hint warning>}}
Pensez à installer avant un serveur de base de données PostgreSQL !
{{</hint>}}

{{<hint info>}}
Cette documentation est fortement inspirée de la [documentation officielle](https://miniflux.app/docs).
{{</hint>}}

## Préparer la base de données

on commence par créer un utilisateur pour le service :

```
CREATE ROLE miniflux WITH LOGIN PASSWORD '<mot de passe fort>';
```

puis on crée la BDD :

```
CREATE DATABASE miniflux WITH OWNER miniflux;
```

Il faut ensuite installer l'extension htsore :

```
CREATE EXTENSION hstore;
```

## Installer le serveur

On commence par se placer dans le dossier `/DATA/miniflux` on y crée le dossier `versions` puis on télécharge l'exécutable (en remplaçant la version et l'architecture) :

```
wget -O versions/miniflux-<version> https://github.com/miniflux/miniflux/releases/download/<version>/miniflux-linux-<arch>
```

on pense à autoriser l'exécution avec

```
chmod +x versions/miniflux-<version>
```

On fait enfin un lien symbolique

```
ln -s /DATA/miniflux/versions/miniflux-<version> /DATA/miniflux/miniflux
```

On va ensuite créer le fichier de configuration su serveur (voir la doc officielle pour plus de détails sur la configuration) `/DATA/miniflux/config` :

```
DATABASE_URL=user=miniflux password=<mon mot de passe> dbname=miniflux sslmode=disable
LISTEN_ADDR=127.0.0.1:5832
BASE_URL=<url d'écoute>
```

On peut enfin lancer notre exécutable pour lancer la migration de la base de données avec :

```
./miniflux --migration -c /DATA/miniflux/config
```

On crée l'administrateur avec :

```
./miniflux -create-admin
```

On peut enfin créer un service systemd dans `/DATA/miniflux/miniflux.service` :

```
[Unit]
Description=Miniflux

After=syslog.target
After=network.target

Requires=postgresql.service

[Service]
RestartSec=2s
Type=simple

ExecStart=/DATA/miniflux/miniflux -c /DATA/miniflux/config
Restart=always

[Install]
WantedBy=multi-user.target
```

puis l'activer avec :

```
sudo systemctl enable --now /DATA/miniflux/miniflux.service
```

## Mise à jour de miniflux

* On télécharge la dernière version de miniflux
* On met à jour le lien symbolique
* On arrête le serveur
* On lance la migration
* On remet en route le serveur
